/**
 * @file
 * Use Slim Select JS.
 */

(function (Drupal, once, drupalSettings) {
  Drupal.behaviors.slimSelect = {
    attach(context) {
      const version = drupalSettings.slimSelectVersion;
      once('slimSelect', '[data-drupal-slim-select]', context).forEach($selectElement => {
        let attr = {};
        try {
          attr = JSON.parse($selectElement.getAttribute('data-drupal-slim-select'));
        } catch (e) {
          console.error('Invalid JSON in data-drupal-slim-select:', e);
        }

        const select = '#' + $selectElement.getAttribute('id');

        // All available settings.
        const settings_available = [
          'disabled',  'alwaysOpen',  'showSearch',  'focusSearch',
          'searchPlaceholder',  'searchText',  'searchingText',
          'searchHighlight',  'closeOnSelect',  'contentLocation',
          'contentPosition',  'openPosition',  'placeholderText',
          'allowDeselect',  'hideSelected',  'showOptionTooltips',
          'minSelected',  'maxSelected',  'timeoutDelay',  'maxValuesShown',
          'maxValuesMessage',  'addableText',
        ];

        // Add translations to the fixed strings.
        let settings = {
          searchPlaceholder: Drupal.t('Search'),
          searchText: Drupal.t('No Results'),
          searchingText: Drupal.t('Searching...'),
        };
        const placeholderText = Drupal.t('Select Value');
        if (version.startsWith('v1.')) {
          settings.placeholder = placeholderText;
        }
        else if (version.startsWith('v2.')) {
          settings.placeholderText = placeholderText;
        }

        // Add the overridden settings.
        Object.keys(attr).forEach(key => {
          if (settings_available.includes(key)) {
            settings[key] = attr[key];
          }
        });

        let options = { select };

        if (version.startsWith('v1.')) {
          // In v1, settings are flattened into top-level options.
          options = { ...options, ...settings };
          if (attr.selectByGroup !== undefined) {
            options.selectByGroup = attr.selectByGroup;
          }
        }
        else if (version.startsWith('v2.')) {
          // In v2, settings are passed as a nested 'settings' object.
          options = { ...options, settings };
        }

        new SlimSelect(options);
      });
    }
  };
})(Drupal, once, drupalSettings);
